"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/* eslint-disable no-console */
var fs_extra_1 = require("fs-extra");
var chalk_1 = tslib_1.__importDefault(require("chalk"));
var path_1 = require("path");
var paths_1 = require("../config/paths");
var updateREADMEFile_1 = tslib_1.__importDefault(require("./fns/updateREADMEFile"));
var updateLicense_1 = tslib_1.__importDefault(require("./fns/updateLicense"));
var genDoczFiles_1 = tslib_1.__importDefault(require("./genDoczFiles"));
/**
 * 更新模块配置信息
 *
 * @param {string} projectPath
 * @param {CreateOptions} options
 */
function updatePackageInfo(projectPath, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var packagePath, packageInfo;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    packagePath = path_1.resolve(projectPath, 'package.json');
                    return [4 /*yield*/, fs_extra_1.readJSON(packagePath)];
                case 1:
                    packageInfo = _a.sent();
                    packageInfo.version = options.packageVersion;
                    packageInfo.name = options.packageName;
                    packageInfo.description = options.packageDescription;
                    return [4 /*yield*/, fs_extra_1.outputJSON(packagePath, packageInfo, {
                            spaces: 2,
                        })];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
/**
 * 更新项目配置
 *
 * @param {string} projectPath
 * @param {CreateOptions} options
 */
function updateProjectConfig(projectPath, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var configPath, projectConfig;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    configPath = path_1.resolve(projectPath, 'ts-lib.config.json');
                    return [4 /*yield*/, fs_extra_1.readJSON(configPath)];
                case 1:
                    projectConfig = _a.sent();
                    projectConfig.npmScope = options.npmScope || options.packageName;
                    return [4 /*yield*/, fs_extra_1.outputJSON(configPath, projectConfig, {
                            spaces: 2,
                        })];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
/**
 * 更新tsconfig配置
 *
 * @param {string} projectPath
 * @param {CreateOptions} options
 */
function updateTsConfig(projectPath, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var tsconfigPath, tsconfig;
        var _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    tsconfigPath = path_1.resolve(projectPath, 'tsconfig.json');
                    return [4 /*yield*/, fs_extra_1.readJSON(tsconfigPath)];
                case 1:
                    tsconfig = _b.sent();
                    tsconfig.paths = (_a = {},
                        _a["@" + (options.npmScope || options.packageName) + "/*"] = ['packages/*/src'],
                        _a);
                    return [4 /*yield*/, fs_extra_1.outputJSON(tsconfigPath, tsconfig, {
                            spaces: 2,
                        })];
                case 2:
                    _b.sent();
                    return [2 /*return*/];
            }
        });
    });
}
/**
 * 生成monorepo模式的项目
 *
 * @param {CreateOptions} options
 */
function genMonorepoProject(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var projectPath, exists;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    projectPath = paths_1.resolveRoot(options.projectName);
                    return [4 /*yield*/, fs_extra_1.pathExists(projectPath)];
                case 1:
                    exists = _a.sent();
                    if (exists) {
                        console.error(chalk_1.default.red("\u5DF2\u7ECF\u5B58\u5728" + options.projectName + "\u6587\u4EF6\u5939\uFF0C\u8BF7\u9009\u62E9\u4E00\u4E2A\u65B0\u7684\u9879\u76EE\u540D\u79F0\u3002"));
                        process.exit(1);
                    }
                    return [4 /*yield*/, fs_extra_1.copy(paths_1.COMMON_TEMPLATE_PATH, projectPath)];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, fs_extra_1.copy(paths_1.MONOREPO_TEMPLATE_PATH, projectPath)];
                case 3:
                    _a.sent();
                    return [4 /*yield*/, fs_extra_1.copy(paths_1.GIT_IGNORE_FILE_PATH, path_1.resolve(projectPath, '.gitignore'))];
                case 4:
                    _a.sent();
                    return [4 /*yield*/, updatePackageInfo(projectPath, options)];
                case 5:
                    _a.sent();
                    return [4 /*yield*/, updateProjectConfig(projectPath, options)];
                case 6:
                    _a.sent();
                    return [4 /*yield*/, updateREADMEFile_1.default(projectPath, options)];
                case 7:
                    _a.sent();
                    return [4 /*yield*/, updateLicense_1.default(projectPath, options)];
                case 8:
                    _a.sent();
                    return [4 /*yield*/, updateTsConfig(projectPath, options)];
                case 9:
                    _a.sent();
                    return [4 /*yield*/, fs_extra_1.remove(path_1.resolve(projectPath, 'src'))];
                case 10:
                    _a.sent();
                    if (!options.docz) return [3 /*break*/, 13];
                    return [4 /*yield*/, genDoczFiles_1.default(projectPath, options)];
                case 11:
                    _a.sent();
                    return [4 /*yield*/, fs_extra_1.remove(path_1.resolve(projectPath, 'docs/Counter.mdx'))];
                case 12:
                    _a.sent();
                    _a.label = 13;
                case 13: return [2 /*return*/];
            }
        });
    });
}
exports.default = genMonorepoProject;
//# sourceMappingURL=genMonorepoProject.js.map