"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var enquirer_1 = require("enquirer");
/**
 * 以交互方式获取配置
 *
 * @param options
 */
function getOptionsWithConfirm(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var confirms, response;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    confirms = [
                        {
                            type: 'input',
                            name: 'pacakgeVersion',
                            message: '项目版本号',
                            initial: options.packageVersion,
                        },
                        {
                            type: 'input',
                            name: 'packageName',
                            initial: options.packageName,
                            message: '项目名称',
                        },
                        {
                            type: 'input',
                            name: 'packageDescription',
                            message: '项目描述',
                        },
                        {
                            type: 'input',
                            name: 'author',
                            message: '作者',
                        },
                    ];
                    return [4 /*yield*/, enquirer_1.prompt(confirms)];
                case 1:
                    response = _a.sent();
                    return [2 /*return*/, tslib_1.__assign({}, options, response)];
            }
        });
    });
}
exports.getOptionsWithConfirm = getOptionsWithConfirm;
/**
 * 获取React组件开发相关的配置
 *
 * @export
 * @param {CreateOptions} options
 * @returns
 */
function getReactOptionsWithConfirm(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var react, docz, doczGithubPages;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, enquirer_1.prompt({
                        type: 'confirm',
                        name: 'react',
                        skip: options.react,
                        message: '开发React组件？',
                        initial: options.react,
                    })];
                case 1:
                    react = (_a.sent()).react;
                    return [4 /*yield*/, enquirer_1.prompt({
                            type: 'confirm',
                            name: 'docz',
                            skip: !react || !!options.docz,
                            message: '使用docz编写组件文档？',
                            initial: react,
                        })];
                case 2:
                    docz = (_a.sent()).docz;
                    return [4 /*yield*/, enquirer_1.prompt({
                            type: 'confirm',
                            name: 'doczGithubPages',
                            skip: function () { return !docz || !!options.doczGithubPages; },
                            message: '将docz文档发布到Github Pages上？',
                            initial: docz,
                        })];
                case 3:
                    doczGithubPages = (_a.sent()).doczGithubPages;
                    return [2 /*return*/, tslib_1.__assign({}, options, { react: react, docz: docz, doczGithubPages: doczGithubPages })];
            }
        });
    });
}
exports.getReactOptionsWithConfirm = getReactOptionsWithConfirm;
/**
 * 获取命令行参数
 *
 * @param projectName 项目名称
 * @param packageName 模块名
 * @param program 命令行程序
 */
function getOptions(projectName, packageName, program) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var options;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    options = {
                        version: program.v,
                        projectName: projectName,
                        packageName: packageName,
                        packageDescription: program.packageDescription,
                        packageVersion: program.packageVersion,
                        react: program.react,
                        monorepo: program.monorepo,
                        npmScope: program.npmScope,
                    };
                    if (!program.i) return [3 /*break*/, 2];
                    return [4 /*yield*/, getOptionsWithConfirm(options)];
                case 1:
                    options = _a.sent();
                    _a.label = 2;
                case 2: return [4 /*yield*/, getReactOptionsWithConfirm(options)];
                case 3:
                    options = _a.sent();
                    return [2 /*return*/, options];
            }
        });
    });
}
exports.getOptions = getOptions;
//# sourceMappingURL=getOptions.js.map